#  Re-order the dimensions of a semantic space, according to the order of
# dimensions in a basis elements file.

# usage: ReorderSpace.rb [SpaceFile] [BEFile] > [NewSpaceFile]

unless ARGV.length == 2
  STDERR.puts "Usage: ReorderSpace.rb [SpaceFile] [BEFile] > [NewSpaceFile]"
  Kernel.exit
end

bes = Array.new # order of BEs according to BEFile
reordering = Array.new # for BE with index i in semantic space file, 
                       # reordering[i] lists the new index

befile = File.new(ARGV[1])
while (line = befile.gets)
  be = line.split("\t").first
  bes.push be
end
befile.close

spacefile = File.new(ARGV[0])
# Read BEs of semantic space file
firstline = spacefile.gets.chomp
space_bes_old = firstline.split("\t")
space_bes_new = Array.new
space_bes_old.each {|be|
  new_index = bes.index(be)
  if new_index.nil?
    STDERR.puts "Error: no mapping for space BE "+be
    Kernel.exit
  end
  reordering.push(new_index) 
  space_bes_new[new_index] = be
}

puts space_bes_new.join("\t")

# Read vectors, reorder, and write
while (line = spacefile.gets)
  line.chomp!
  old_vector = line.strip.split(" ")
  target = old_vector.shift
  unless old_vector.length == reordering.length
    STDERR.puts "Error: vector has wrong length."
  end
  new_vector = Array.new
  old_vector.each_index {|i|
    new_vector[reordering[i]] = old_vector[i]
  }
  puts [[target]+new_vector].join(" ")
end

spacefile.close
