/**
   class Context

   Copyright (C) 2002-4 Sebastian Pado
   
   This file is part of the DependencyVectors v2 distribution.
   
   DependencyVectors is free software; you can redistribute it
   and/or modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later
   version.
   
   DependencyVectors is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied
   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
   PURPOSE.  See the GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public
   License along with DependencyVectors; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
   MA 02111-1307 USA

**/

package de.ims.cl.dv.datastructures;

import java.util.*;


/** This class models a word's context as determined by the context
    specification function. This is a set of anchored paths, i.e. all
    paths in the context begin at this particular word. The current
    implementation contains another invariant, namely that every path
    conforms to a context specification (ContextSpec) path template.  </ul>
 **/

public class Context implements Iterable<Path> {
    
    Set<Path> context;

    /** returns an iterator over all paths in the context.
     **/
    
    public Iterator<Path> iterator() {
	return context.iterator();
    }
    
    public int size() {
	return context.size();
    }


    // try to find Paths starting from word conforming to some spec
    
    // uses depth-first search
    
    private void findPaths(Graph g, Path pathSpec, Integer lastIndex, Path p) {
	if (pathSpec.size() == 0 ) { // found a complete path
       	    this.context.add(p);
	    // System.out.println(p.toString());
	} else {
	    Edge edgeSpec = (Edge) pathSpec.get(0);
	    pathSpec.remove(0);
	    //	    System.err.println("Retrieving edges for node "+lastIndex);
	    Map<Integer,Edge> nextEdges = g.getEdges(lastIndex);
	    Set<Integer> nextIndices = nextEdges.keySet();
	    for (Integer nextIndex: nextIndices) {
		Edge nextEdge = nextEdges.get(nextIndex);
		if ((!(p.yield().contains(nextEdge.getToNode()))) && // avoid cyclic paths
		    (edgeSpec.matches(nextEdge)))
		    {
			Path newPath = (Path) p.clone();
			newPath.add(nextEdge);
			findPaths(g,pathSpec,nextIndex,newPath);
		    }
	    }
	}
    }
    
    
    /** A Context is constructed by specifying a (parse) graph, a context specification, and 
	the index of the word in question.
    **/
    
    public Context(Graph g, ContextSpec cs, Integer wordIndex) {
	// the context is determined by extracting all paths beginning
	// at a particular word which conform to any of the path specifications 
	// in the context specification.

	context = new HashSet<Path>();
	Iterator<Path> csit = cs.iterator();
	while (csit.hasNext()) {
	    Path pathspec = (Path) ((Path) csit.next()).clone();
	    findPaths(g, pathspec, wordIndex, new Path()); 
	} 
    }       
}




