/**
   class Edge

   Copyright (C) 2002-4 Sebastian Pado
   
   This file is part of the DependencyVectors v2 distribution.
   
   DependencyVectors is free software; you can redistribute it
   and/or modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later
   version.
   
   DependencyVectors is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied
   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
   PURPOSE.  See the GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public
   License along with DependencyVectors; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
   MA 02111-1307 USA

**/

package de.ims.cl.dv.datastructures;


/** This class models an edge of a parse tree, that is an edge between
    two Nodes with a String label called relation. **/

public class Edge {

    Node fromNode;
    Node toNode;
    public String rel;
    
    /** Get the node object  at which the edge starts **/
    public Node getFromNode(){
	return fromNode;
    }
    
    /** Get the node object at which the edge ends **/
    public Node getToNode() {
	return toNode;
    }
    
    /** Get the relation with which the edge is labelled **/
    public String getRelation() {
	return rel;
    }
    
    /** Returns a string representation of the edge (equivalent to the edge part of a path specification) **/
    public String toString() {
	return 
	    fromNode.getWord()+":"+
	    fromNode.getPOS()+":"+
	    rel+":"+
	    toNode.getPOS()+":"+
	    toNode.getWord();
    }
    
    /** Returns a new edge which has the start and end nodes inversed. **/
    public Edge invert() {
	return new Edge(toNode,
			fromNode,
			rel);
    }
    
    /** Checks if two edges match. This is true iff the start and end
	nodes of both edges match (see the Node class for details) and
	the relation matches.  The relation matches iff the two relations
	are identical or one of them is "*". This method is used to check
	if an edge matches part of a path specification
    **/
    public boolean matches(Edge e) {
	Node otherFromNode = e.getFromNode();
	Node otherToNode = e.getToNode();
	return
	    ((fromNode.matches(otherFromNode)) && 
	     (toNode.matches(otherToNode)) &&
	     (rel.equals("*") || e.getRelation().startsWith(rel) || e.getRelation().equals("*")));
    }

    /** Constructs an edge from two nodes an a label (relation). **/
    public Edge(Node fromNode, Node toNode, String relation) {
	this.fromNode = fromNode;
	this.toNode = toNode;
	this.rel = relation;
    }

}
