/**
   class Node
   
   Copyright (C) 2002-4 Sebastian Pado
   
   This file is part of the DependencyVectors v2 distribution.
   
   DependencyVectors is free software; you can redistribute it
   and/or modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later
   version.
   
   DependencyVectors is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied
   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
   PURPOSE.  See the GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public
   License along with DependencyVectors; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
   MA 02111-1307 USA
**/

package de.ims.cl.dv.datastructures;

import de.ims.cl.dv.parsers.Encoding;

/** This class models a Node. A node has a word and a part of
 * speech. It can be in a graph, in which case it additionally has an
 * index, but it does not have to. **/

public class Node {

    String word;
    String pos;
    Integer index;
    
    /** Returns the word **/
    public String getWord() {
        return word;
    }

    /** Returns the part of speech **/
    public String getPOS() {
        return pos;
    }
    
    /** Returns the index (if present). If no index is present, a NullPointerException is thrown. **/
    
    public Integer getIndex() {
        if (index!=null){
            return index;
        } else {
            throw new NullPointerException("Uninitialised index in node");
        }
    }
    
    /** overwrite POS of a node **/
    public void setPOS(String newpos) {
        pos = newpos;
    }
    
    /** Returns a string representation of the Node object. **/
    
    public String toString() {
    return word+" ("+pos+")";
    }
    
    /** Two nodes match iff their words and parts of speech are equal, or if either 
    is a wildcard ("*") **/
    public boolean matches (Node n) {
    return ((word.equals("*") || word.equals(n.getWord()) || n.getWord().equals("*")) &&
        (pos.equals("*") || pos.equals(n.getPOS()) || n.getPOS().equals("*")));
    }

    
    public Node(String word, String pos, Integer index, Encoding e) {
        this(word,pos,e);
        this.index = index;
    }
    
    /** Initialisation for a node without an index (word, POS)  **/

 
    public Node(String word, String pos, Encoding e) {    
        this.word = e.encode(word);
        this.pos  = e.encode(pos);
        this.index = null;        
    }
    
    public Node(String word, String pos, Integer index){
        this(word,pos);
        this.index = index;
    }
    
    public Node(String word, String pos){
        this.word  = word;
        this.pos   = pos;
        this.index = null;
    }
    
}
