/**
   class Corpus

   Copyright (C) 2002-4 Sebastian Pado
   
   This file is part of the DependencyVectors v2 distribution.
   
   DependencyVectors is free software; you can redistribute it
   and/or modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later
   version.
   
   DependencyVectors is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied
   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
   PURPOSE.  See the GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public
   License along with DependencyVectors; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
   MA 02111-1307 USA

**/

package de.ims.cl.dv.parsers;

import java.util.Arrays;
import java.util.Comparator;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

import de.ims.cl.dv.datastructures.*;


/**
 * This class decides whether the first Edge is "more informative" than the second
 * depending on the edge label. The idea is that we are more interested in "subj" and 
 * "obj" than, for example, in "s".
 * 
 * @author pado
 *
 */
class MiniparEdgeComparator implements Comparator<Edge> {

    final String[] srArray =  {"s","i"};
    final String[] drArray = {"subj","obj"};
    final Set<String> surfaceRelations= new HashSet<String>(Arrays.asList(srArray));
    final Set<String> deepRelations = new HashSet<String>(Arrays.asList(drArray));
    
    public int compare(Edge e1, Edge e2) {
    if (deepRelations.contains(e1.rel) && surfaceRelations.contains(e2.rel)) {
        return 1;
    } else {
       return 0;
    }
    }

}




/** A Corpus is a sequence of dependency parses. It only allows sequentual reading of parses.    
 **/

public interface Corpus extends Iterator<Graph> {

	public long charcounter();
	
    public Graph next();

    public boolean hasNext();
    
}

