/**
   interface SemanticSpace

   Copyright (C) 2002-4 Sebastian Pado
   
   This file is part of the DependencyVectors v2 distribution.
   
   DependencyVectors is free software; you can redistribute it
   and/or modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later
   version.
   
   DependencyVectors is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied
   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
   PURPOSE.  See the GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public
   License along with DependencyVectors; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
   MA 02111-1307 USA

**/

package de.ims.cl.dv.space;


/** This interface models a basic semantic space, that is a matrix in
 * which <i>targets</i> are represented as vectors. The dimensions of
 * these vectors are <i>basis elements</i>, and the cells contain the
 * respective co-occurrence frequencies. This interface could (or
 * should?) be richer, but some methods (such as log-likelihood
 * transformation) are currently only available in the
 * SemanticSpaceArray implementation.
 **/

public interface SemanticSpace {

    /** Increases the co-occurrence count for a given target and basis element combination.
     **/
    public void increaseCount(String target, String be, double value);
    /** Returns a string representation of the semantic space. **/
    public String toString();
    /** Determines if the target t is represented in the semantic space. **/
    public boolean containsTarget(String t);
    /** Determines if the basis element b is used for representation in the semantic space. **/
    public boolean containsBE(String b);
}
